==> cirq-0.4.0.dev4220181107204838-py3-none-any.whl: cirq/google/__init__.py <==
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from cirq.google.convert_to_xmon_gates import (
    ConvertToXmonGates,
)
from cirq.google.decompositions import (
    controlled_op_to_native_gates,
    single_qubit_matrix_to_native_gates,
)
from cirq.google.eject_full_w import (
    EjectFullW,
)
from cirq.google.known_devices import (
    Bristlecone,
    Foxtail,
)
from cirq.google.merge_rotations import (
    MergeRotations,
)
from cirq.google.xmon_device import (
    XmonDevice,
)
from cirq.google.optimize import (
    optimized_for_xmon,
)
from cirq.google.sim import (
    XmonOptions,
    XmonSimulator,
    XmonStepResult,
)
from cirq.google.engine import (
    engine_from_environment,
    Engine,
    JobConfig,
)
from cirq.google.programs import (
    gate_to_proto_dict,
    is_native_xmon_op,
    schedule_from_proto_dicts,
    schedule_to_proto_dicts,
    pack_results,
    unpack_results,
    xmon_op_from_proto_dict,
)

from cirq.google.line import (
    AnnealSequenceSearchStrategy,
    GreedySequenceSearchStrategy,
    LinePlacementStrategy,
    line_on_device,
)

==> cirq-0.6.0.dev20190618134705-py3-none-any.whl: cirq/google/__init__.py <==
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from cirq.google.engine import (
    engine_from_environment,
    Engine,
    JobConfig,
)

from cirq.google.line import (
    AnnealSequenceSearchStrategy,
    GreedySequenceSearchStrategy,
    line_on_device,
    LinePlacementStrategy,
)

from cirq.google.sim import (
    XmonOptions,
    XmonSimulator,
    XmonStepResult,
)


from cirq.google.convert_to_xmon_gates import (
    ConvertToXmonGates,)

from cirq.google.gate_sets import (
    XMON,)

from cirq.google.known_devices import (
    Bristlecone,
    Foxtail,
)

from cirq.google.op_deserializer import (
    DeserializingArg,
    GateOpDeserializer,
)

from cirq.google.op_serializer import (GateOpSerializer, SerializingArg)

from cirq.google.optimize import (
    optimized_for_xmon,)

from cirq.google.programs import (
    gate_to_proto_dict,
    is_native_xmon_gate,
    is_native_xmon_op,
    pack_results,
    schedule_from_proto_dicts,
    schedule_to_proto_dicts,
    unpack_results,
    xmon_op_from_proto_dict,
)

from cirq.google.serializable_gate_set import (
    SerializableGateSet,)

from cirq.google.xmon_device import (
    XmonDevice,)
